@font-face {
    font-family: 'zondicon';
    src: url('../fonts/zondicon.eot?sm22ej');
    src: url('../fonts/zondicon.eot?sm22ej#iefix') format('embedded-opentype'),
        url('../fonts/zondicon.ttf?sm22ej') format('truetype'),
        url('../fonts/zondicon.woff?sm22ej') format('woff'),
        url('../fonts/zondicon.svg?sm22ej#zondicon') format('svg');
    font-weight: normal;
    font-style: normal;
}

.zi {
    /* use !important to prevent issues with browser extensions that change fonts */
    font-family: 'zondicon' !important;
    speak: none;
    font-style: normal;
    font-weight: normal;
    font-variant: normal;
    text-transform: none;
    line-height: 1;

    /* Better Font Rendering =========== */
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.zi-zoom-out:before {
    content: "\e900";
}

.zi-zoom-in:before {
    content: "\e901";
}

.zi-yin-yang:before {
    content: "\e902";
}

.zi-wrench:before {
    content: "\e903";
}

.zi-window:before {
    content: "\e904";
}

.zi-window-open:before {
    content: "\e905";
}

.zi-window-new:before {
    content: "\e906";
}

.zi-watch:before {
    content: "\e907";
}

.zi-wallet:before {
    content: "\e908";
}

.zi-volume-up:before {
    content: "\e909";
}

.zi-volume-off:before {
    content: "\e90a";
}

.zi-volume-mute:before {
    content: "\e90b";
}

.zi-volume-down:before {
    content: "\e90c";
}

.zi-view-tile:before {
    content: "\e90d";
}

.zi-view-show:before {
    content: "\e90e";
}

.zi-view-list:before {
    content: "\e90f";
}

.zi-view-hide:before {
    content: "\e910";
}

.zi-view-column:before {
    content: "\e911";
}

.zi-view-carousel:before {
    content: "\e912";
}

.zi-video-camera:before {
    content: "\e913";
}

.zi-vector:before {
    content: "\e914";
}

.zi-user:before {
    content: "\e915";
}

.zi-user-solid-square:before {
    content: "\e916";
}

.zi-user-solid-circle:before {
    content: "\e917";
}

.zi-user-group:before {
    content: "\e918";
}

.zi-user-add:before {
    content: "\e919";
}

.zi-usb:before {
    content: "\e91a";
}

.zi-upload:before {
    content: "\e91b";
}

.zi-tuning:before {
    content: "\e91c";
}

.zi-trophy:before {
    content: "\e91d";
}

.zi-travel:before {
    content: "\e91e";
}

.zi-travel-walk:before {
    content: "\e91f";
}

.zi-travel-train:before {
    content: "\e920";
}

.zi-travel-taxi-cab:before {
    content: "\e921";
}

.zi-travel-case:before {
    content: "\e922";
}

.zi-travel-car:before {
    content: "\e923";
}

.zi-travel-bus:before {
    content: "\e924";
}

.zi-trash:before {
    content: "\e925";
}

.zi-translate:before {
    content: "\e926";
}

.zi-tools-copy:before {
    content: "\e927";
}

.zi-timer:before {
    content: "\e928";
}

.zi-time:before {
    content: "\e929";
}

.zi-ticket:before {
    content: "\e92a";
}

.zi-thumbs-up:before {
    content: "\e92b";
}

.zi-thumbs-down:before {
    content: "\e92c";
}

.zi-thermometer:before {
    content: "\e92d";
}

.zi-text-decoration:before {
    content: "\e92e";
}

.zi-text-box:before {
    content: "\e92f";
}

.zi-target:before {
    content: "\e930";
}

.zi-tag:before {
    content: "\e931";
}

.zi-tablet:before {
    content: "\e932";
}

.zi-swap:before {
    content: "\e933";
}

.zi-subdirectory-right:before {
    content: "\e934";
}

.zi-subdirectory-left:before {
    content: "\e935";
}

.zi-stroke-width:before {
    content: "\e936";
}

.zi-store-front:before {
    content: "\e937";
}

.zi-stethoscope:before {
    content: "\e938";
}

.zi-step-forward:before {
    content: "\e939";
}

.zi-step-backward:before {
    content: "\e93a";
}

.zi-station:before {
    content: "\e93b";
}

.zi-star-full:before {
    content: "\e93c";
}

.zi-stand-by:before {
    content: "\e93d";
}

.zi-shuffle:before {
    content: "\e93e";
}

.zi-show-sidebar:before {
    content: "\e93f";
}

.zi-shopping-cart:before {
    content: "\e940";
}

.zi-shield:before {
    content: "\e941";
}

.zi-share:before {
    content: "\e942";
}

.zi-share-alt:before {
    content: "\e943";
}

.zi-share-01:before {
    content: "\e944";
}

.zi-servers:before {
    content: "\e945";
}

.zi-send:before {
    content: "\e946";
}

.zi-search:before {
    content: "\e947";
}

.zi-screen-full:before {
    content: "\e948";
}

.zi-save-disk:before {
    content: "\e949";
}

.zi-repost:before {
    content: "\e94a";
}

.zi-reply:before {
    content: "\e94b";
}

.zi-reply-all:before {
    content: "\e94c";
}

.zi-reload:before {
    content: "\e94d";
}

.zi-refresh:before {
    content: "\e94e";
}

.zi-radio:before {
    content: "\e94f";
}

.zi-radar:before {
    content: "\e950";
}

.zi-radar-copy-2:before {
    content: "\e951";
}

.zi-queue:before {
    content: "\e952";
}

.zi-question:before {
    content: "\e953";
}

.zi-pylon:before {
    content: "\e954";
}

.zi-printer:before {
    content: "\e955";
}

.zi-portfolio:before {
    content: "\e956";
}

.zi-plugin:before {
    content: "\e957";
}

.zi-playlist:before {
    content: "\e958";
}

.zi-play:before {
    content: "\e959";
}

.zi-play-outline:before {
    content: "\e95a";
}

.zi-pin:before {
    content: "\e95b";
}

.zi-php-elephant:before {
    content: "\e95c";
}

.zi-photo:before {
    content: "\e95d";
}

.zi-phone:before {
    content: "\e95e";
}

.zi-pen-tool:before {
    content: "\e95f";
}

.zi-pause:before {
    content: "\e960";
}

.zi-pause-solid:before {
    content: "\e961";
}

.zi-pause-outline:before {
    content: "\e962";
}

.zi-paste:before {
    content: "\e963";
}

.zi-notifications:before {
    content: "\e964";
}

.zi-notifications-outline:before {
    content: "\e965";
}

.zi-notification:before {
    content: "\e966";
}

.zi-news-paper:before {
    content: "\e967";
}

.zi-network:before {
    content: "\e968";
}

.zi-navigation-more:before {
    content: "\e969";
}

.zi-music-playlist:before {
    content: "\e96a";
}

.zi-music-notes:before {
    content: "\e96b";
}

.zi-music-artist:before {
    content: "\e96c";
}

.zi-music-album:before {
    content: "\e96d";
}

.zi-mouse:before {
    content: "\e96e";
}

.zi-mood-sad-solid:before {
    content: "\e96f";
}

.zi-mood-sad-outline:before {
    content: "\e970";
}

.zi-mood-neutral-solid:before {
    content: "\e971";
}

.zi-mood-neutral-outline:before {
    content: "\e972";
}

.zi-mood-happy-solid:before {
    content: "\e973";
}

.zi-mood-happy-outline:before {
    content: "\e974";
}

.zi-mobile-devices:before {
    content: "\e975";
}

.zi-minus-solid:before {
    content: "\e976";
}

.zi-minus-outline:before {
    content: "\e977";
}

.zi-mic:before {
    content: "\e978";
}

.zi-menu:before {
    content: "\e979";
}

.zi-map:before {
    content: "\e97a";
}

.zi-lock-open:before {
    content: "\e97b";
}

.zi-lock-closed:before {
    content: "\e97c";
}

.zi-location:before {
    content: "\e97d";
}

.zi-location-shopping:before {
    content: "\e97e";
}

.zi-location-restroom:before {
    content: "\e97f";
}

.zi-location-park:before {
    content: "\e980";
}

.zi-location-marina:before {
    content: "\e981";
}

.zi-location-hotel:before {
    content: "\e982";
}

.zi-location-gas-station:before {
    content: "\e983";
}

.zi-location-food:before {
    content: "\e984";
}

.zi-location-current:before {
    content: "\e985";
}

.zi-load-balancer:before {
    content: "\e986";
}

.zi-list:before {
    content: "\e987";
}

.zi-list-bullet:before {
    content: "\e988";
}

.zi-list-add:before {
    content: "\e989";
}

.zi-link:before {
    content: "\e98a";
}

.zi-light-bulb:before {
    content: "\e98b";
}

.zi-library:before {
    content: "\e98c";
}

.zi-layers:before {
    content: "\e98d";
}

.zi-keyboard:before {
    content: "\e98e";
}

.zi-key:before {
    content: "\e98f";
}

.zi-information-solid:before {
    content: "\e990";
}

.zi-information-outline:before {
    content: "\e991";
}

.zi-indent-increase:before {
    content: "\e992";
}

.zi-indent-decrease:before {
    content: "\e993";
}

.zi-inbox:before {
    content: "\e994";
}

.zi-inbox-full:before {
    content: "\e995";
}

.zi-inbox-download:before {
    content: "\e996";
}

.zi-inbox-check:before {
    content: "\e997";
}

.zi-hour-glass:before {
    content: "\e998";
}

.zi-hot:before {
    content: "\e999";
}

.zi-home:before {
    content: "\e99a";
}

.zi-heart:before {
    content: "\e99b";
}

.zi-headphones:before {
    content: "\e99c";
}

.zi-hard-drive:before {
    content: "\e99d";
}

.zi-hand-stop:before {
    content: "\e99e";
}

.zi-globe:before {
    content: "\e99f";
}

.zi-gift:before {
    content: "\e9a0";
}

.zi-forward:before {
    content: "\e9a1";
}

.zi-forward-step:before {
    content: "\e9a2";
}

.zi-format-underline:before {
    content: "\e9a3";
}

.zi-format-text-size:before {
    content: "\e9a4";
}

.zi-format-italic:before {
    content: "\e9a5";
}

.zi-format-font-size:before {
    content: "\e9a6";
}

.zi-format-bold:before {
    content: "\e9a7";
}

.zi-folder:before {
    content: "\e9a8";
}

.zi-folder-outline:before {
    content: "\e9a9";
}

.zi-folder-outline-add:before {
    content: "\e9aa";
}

.zi-flashlight:before {
    content: "\e9ab";
}

.zi-flag:before {
    content: "\e9ac";
}

.zi-filter:before {
    content: "\e9ad";
}

.zi-film:before {
    content: "\e9ae";
}

.zi-fast-rewind:before {
    content: "\e9af";
}

.zi-fast-forward:before {
    content: "\e9b0";
}

.zi-factory:before {
    content: "\e9b1";
}

.zi-explore:before {
    content: "\e9b2";
}

.zi-exclamation-solid:before {
    content: "\e9b3";
}

.zi-exclamation-outline:before {
    content: "\e9b4";
}

.zi-envelope:before {
    content: "\e9b5";
}

.zi-education:before {
    content: "\e9b6";
}

.zi-edit-pencil:before {
    content: "\e9b7";
}

.zi-edit-cut:before {
    content: "\e9b8";
}

.zi-edit-crop:before {
    content: "\e9b9";
}

.zi-edit-copy:before {
    content: "\e9ba";
}

.zi-duplicate:before {
    content: "\e9bb";
}

.zi-download:before {
    content: "\e9bc";
}

.zi-dots-horizontal-triple:before {
    content: "\e9bd";
}

.zi-dots-horizontal-double:before {
    content: "\e9be";
}

.zi-document:before {
    content: "\e9bf";
}

.zi-document-add:before {
    content: "\e9c0";
}

.zi-directions:before {
    content: "\e9c1";
}

.zi-dial-pad:before {
    content: "\e9c2";
}

.zi-date-add:before {
    content: "\e9c3";
}

.zi-dashboard:before {
    content: "\e9c4";
}

.zi-currency-dollar:before {
    content: "\e9c5";
}

.zi-credit-card:before {
    content: "\e9c6";
}

.zi-copy:before {
    content: "\e9c7";
}

.zi-conversation:before {
    content: "\e9c8";
}

.zi-computer-laptop:before {
    content: "\e9c9";
}

.zi-computer-desktop:before {
    content: "\e9ca";
}

.zi-compose:before {
    content: "\e9cb";
}

.zi-color-palette:before {
    content: "\e9cc";
}

.zi-cog:before {
    content: "\e9cd";
}

.zi-coffee:before {
    content: "\e9ce";
}

.zi-code:before {
    content: "\e9cf";
}

.zi-cloud:before {
    content: "\e9d0";
}

.zi-cloud-upload:before {
    content: "\e9d1";
}

.zi-close:before {
    content: "\e9d2";
}

.zi-close-solid:before {
    content: "\e9d3";
}

.zi-close-outline:before {
    content: "\e9d4";
}

.zi-clipboard:before {
    content: "\e9d5";
}

.zi-cheveron-up:before {
    content: "\e9d6";
}

.zi-cheveron-right:before {
    content: "\e9d7";
}

.zi-cheveron-outline-up:before {
    content: "\e9d8";
}

.zi-cheveron-outline-right:before {
    content: "\e9d9";
}

.zi-cheveron-outline-left:before {
    content: "\e9da";
}

.zi-cheveron-outline-down:before {
    content: "\e9db";
}

.zi-cheveron-left:before {
    content: "\e9dc";
}

.zi-cheveron-down:before {
    content: "\e9dd";
}

.zi-checkmark:before {
    content: "\e9de";
}

.zi-checkmark-outline:before {
    content: "\e9df";
}

.zi-chat-bubble-dots:before {
    content: "\e9e0";
}

.zi-chart:before {
    content: "\e9e1";
}

.zi-chart-pie:before {
    content: "\e9e2";
}

.zi-chart-bar:before {
    content: "\e9e3";
}

.zi-camera:before {
    content: "\e9e4";
}

.zi-calendar:before {
    content: "\e9e5";
}

.zi-calculator:before {
    content: "\e9e6";
}

.zi-buoy:before {
    content: "\e9e7";
}

.zi-bug:before {
    content: "\e9e8";
}

.zi-browser-window:before {
    content: "\e9e9";
}

.zi-browser-window-open:before {
    content: "\e9ea";
}

.zi-browser-window-new:before {
    content: "\e9eb";
}

.zi-brightness-up:before {
    content: "\e9ec";
}

.zi-brightness-down:before {
    content: "\e9ed";
}

.zi-box:before {
    content: "\e9ee";
}

.zi-border-vertical:before {
    content: "\e9ef";
}

.zi-border-top:before {
    content: "\e9f0";
}

.zi-border-right:before {
    content: "\e9f1";
}

.zi-border-outer:before {
    content: "\e9f2";
}

.zi-border-none:before {
    content: "\e9f3";
}

.zi-border-left:before {
    content: "\e9f4";
}

.zi-border-inner:before {
    content: "\e9f5";
}

.zi-border-horizontal:before {
    content: "\e9f6";
}

.zi-border-bottom:before {
    content: "\e9f7";
}

.zi-border-all:before {
    content: "\e9f8";
}

.zi-bookmark:before {
    content: "\e9f9";
}

.zi-bookmark-outline:before {
    content: "\e9fa";
}

.zi-bookmark-outline-add:before {
    content: "\e9fb";
}

.zi-bookmark-copy-3:before {
    content: "\e9fc";
}

.zi-bookmark-copy-2:before {
    content: "\e9fd";
}

.zi-book-reference:before {
    content: "\e9fe";
}

.zi-bolt:before {
    content: "\e9ff";
}

.zi-bluetooth:before {
    content: "\ea00";
}

.zi-block:before {
    content: "\ea01";
}

.zi-beverage:before {
    content: "\ea02";
}

.zi-battery-low:before {
    content: "\ea03";
}

.zi-battery-half:before {
    content: "\ea04";
}

.zi-battery-full:before {
    content: "\ea05";
}

.zi-badge:before {
    content: "\ea06";
}

.zi-backward:before {
    content: "\ea07";
}

.zi-backward-step:before {
    content: "\ea08";
}

.zi-backspace:before {
    content: "\ea09";
}

.zi-attachment:before {
    content: "\ea0a";
}

.zi-at-symbol:before {
    content: "\ea0b";
}

.zi-artist:before {
    content: "\ea0c";
}

.zi-arrow-up:before {
    content: "\ea0d";
}

.zi-arrow-thin-up:before {
    content: "\ea0e";
}

.zi-arrow-thin-right:before {
    content: "\ea0f";
}

.zi-arrow-thin-left:before {
    content: "\ea10";
}

.zi-arrow-thin-down:before {
    content: "\ea11";
}

.zi-arrow-thick-up:before {
    content: "\ea12";
}

.zi-arrow-thick-right:before {
    content: "\ea13";
}

.zi-arrow-thick-left:before {
    content: "\ea14";
}

.zi-arrow-thick-down:before {
    content: "\ea15";
}

.zi-arrow-right:before {
    content: "\ea16";
}

.zi-arrow-outline-up:before {
    content: "\ea17";
}

.zi-arrow-outline-right:before {
    content: "\ea18";
}

.zi-arrow-outline-left:before {
    content: "\ea19";
}

.zi-arrow-outline-down:before {
    content: "\ea1a";
}

.zi-arrow-left:before {
    content: "\ea1b";
}

.zi-arrow-down:before {
    content: "\ea1c";
}

.zi-apparel:before {
    content: "\ea1d";
}

.zi-announcement:before {
    content: "\ea1e";
}

.zi-anchor:before {
    content: "\ea1f";
}

.zi-align-right:before {
    content: "\ea20";
}

.zi-align-left:before {
    content: "\ea21";
}

.zi-align-justified:before {
    content: "\ea22";
}

.zi-align-center:before {
    content: "\ea23";
}

.zi-album:before {
    content: "\ea24";
}

.zi-airplane:before {
    content: "\ea25";
}

.zi-adjust:before {
    content: "\ea26";
}

.zi-add-solid:before {
    content: "\ea27";
}

.zi-add-outline:before {
    content: "\ea28";
}
