@font-face {
    font-family: 'Happy Icons';
    src: url('../fonts/happy-icons.woff2') format('woff2'),
        url('../fonts/happy-icons.woff') format('woff'),
        url('../fonts/happy-icons.svg#happy-icons') format('svg');
    font-weight: normal;
    font-style: normal;
    font-display: swap;
}

.hm,
.fashm {
    /* use !important to prevent issues with browser extensions that change fonts */
    font-family: 'Happy Icons' !important;
    speak: none;
    font-style: normal;
    font-weight: normal;
    font-variant: normal;
    text-transform: none;
    line-height: 1;

    /* Better Font Rendering =========== */
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}

.hm-3d-rotate:before {
    content: "\e900";
}

.hm-degree:before {
    content: "\e901";
}

.hm-accordion-horizontal:before {
    content: "\e902";
}

.hm-accordion-vertical:before {
    content: "\e903";
}

.hm-alarm-clock:before {
    content: "\e904";
}

.hm-alien-gun:before {
    content: "\e905";
}

.hm-alien:before {
    content: "\e906";
}

.hm-anchor:before {
    content: "\e907";
}

.hm-android:before {
    content: "\e908";
}

.hm-angle-down:before {
    content: "\e909";
}

.hm-angle-left:before {
    content: "\e90a";
}

.hm-angle-right:before {
    content: "\e90b";
}

.hm-angle-up:before {
    content: "\e90c";
}

.hm-apple:before {
    content: "\e90d";
}

.hm-arrow-left:before {
    content: "\e90e";
}

.hm-arrow-right:before {
    content: "\e90f";
}

.hm-arrow-zoom-out:before {
    content: "\e910";
}

.hm-arrow-corner:before {
    content: "\e911";
}

.hm-arrow-down:before {
    content: "\e912";
}

.hm-arrow-left1:before {
    content: "\e913";
}

.hm-arrow-right1:before {
    content: "\e914";
}

.hm-arrow-up:before {
    content: "\e915";
}

.hm-article:before {
    content: "\e916";
}

.hm-avatar-man:before {
    content: "\e917";
}

.hm-avatar-woman:before {
    content: "\e918";
}

.hm-badge1:before {
    content: "\e919";
}

.hm-badge2:before {
    content: "\e91a";
}

.hm-badge3:before {
    content: "\e91b";
}

.hm-bamboo:before {
    content: "\e91c";
}

.hm-basketball:before {
    content: "\e91d";
}

.hm-battery:before {
    content: "\e91e";
}

.hm-beach-seat:before {
    content: "\e91f";
}

.hm-bell:before {
    content: "\e920";
}

.hm-bicycle:before {
    content: "\e921";
}

.hm-blog-content:before {
    content: "\e922";
}

.hm-bluetooth:before {
    content: "\e923";
}

.hm-board:before {
    content: "\e924";
}

.hm-body:before {
    content: "\e925";
}

.hm-bomb:before {
    content: "\e926";
}

.hm-bond-hand:before {
    content: "\e927";
}

.hm-bond:before {
    content: "\e928";
}

.hm-bonsai:before {
    content: "\e929";
}

.hm-book:before {
    content: "\e92a";
}

.hm-bowl:before {
    content: "\e92b";
}

.hm-brick-wall:before {
    content: "\e92c";
}

.hm-brush-paint:before {
    content: "\e92d";
}

.hm-brush-roll:before {
    content: "\e92e";
}

.hm-brush:before {
    content: "\e92f";
}

.hm-bug:before {
    content: "\e930";
}

.hm-bulb:before {
    content: "\e931";
}

.hm-calculation:before {
    content: "\e932";
}

.hm-calendar:before {
    content: "\e933";
}

.hm-camera:before {
    content: "\e934";
}

.hm-candle:before {
    content: "\e935";
}

.hm-candles:before {
    content: "\e936";
}

.hm-car:before {
    content: "\e937";
}

.hm-card:before {
    content: "\e938";
}

.hm-caret-down:before {
    content: "\e939";
}

.hm-caret-fill-down:before {
    content: "\e93a";
}

.hm-caret-fill-left:before {
    content: "\e93b";
}

.hm-caret-fill-right:before {
    content: "\e93c";
}

.hm-caret-fill-up:before {
    content: "\e93d";
}

.hm-caret-left:before {
    content: "\e93e";
}

.hm-caret-right:before {
    content: "\e93f";
}

.hm-caret-up:before {
    content: "\e940";
}

.hm-carousal:before {
    content: "\e941";
}

.hm-cart-empty:before {
    content: "\e942";
}

.hm-cart-full:before {
    content: "\e943";
}

.hm-caution:before {
    content: "\e944";
}

.hm-chair:before {
    content: "\e945";
}

.hm-chair2:before {
    content: "\e946";
}

.hm-chat-bubble-single:before {
    content: "\e947";
}

.hm-chat-bubble:before {
    content: "\e948";
}

.hm-cheese:before {
    content: "\e949";
}

.hm-chef-cap:before {
    content: "\e94a";
}

.hm-clip-board:before {
    content: "\e94b";
}

.hm-clip:before {
    content: "\e94c";
}

.hm-cloud-down:before {
    content: "\e94d";
}

.hm-cloud-up:before {
    content: "\e94e";
}

.hm-cloud:before {
    content: "\e94f";
}

.hm-code-browser:before {
    content: "\e950";
}

.hm-code-clean:before {
    content: "\e951";
}

.hm-code:before {
    content: "\e952";
}

.hm-cog:before {
    content: "\e953";
}

.hm-color-card:before {
    content: "\e954";
}

.hm-color-plate:before {
    content: "\e955";
}

.hm-compass-math:before {
    content: "\e956";
}

.hm-compass:before {
    content: "\e957";
}

.hm-corner:before {
    content: "\e958";
}

.hm-crop:before {
    content: "\e959";
}

.hm-cross-circle:before {
    content: "\e95a";
}

.hm-cross-game:before {
    content: "\e95b";
}

.hm-cross-gap:before {
    content: "\e95c";
}

.hm-cross:before {
    content: "\e95d";
}

.hm-crown:before {
    content: "\e95e";
}

.hm-cube:before {
    content: "\e95f";
}

.hm-cup-coffee:before {
    content: "\e960";
}

.hm-cup:before {
    content: "\e961";
}

.hm-currency-paper:before {
    content: "\e962";
}

.hm-dashboard:before {
    content: "\e963";
}

.hm-delivery-van:before {
    content: "\e964";
}

.hm-diamond-ring:before {
    content: "\e965";
}

.hm-direction-both:before {
    content: "\e966";
}

.hm-direction-right:before {
    content: "\e967";
}

.hm-disable-person:before {
    content: "\e968";
}

.hm-disc:before {
    content: "\e969";
}

.hm-dislike:before {
    content: "\e96a";
}

.hm-dollar-on-hand:before {
    content: "\e96b";
}

.hm-door-path:before {
    content: "\e96c";
}

.hm-Download-circle:before {
    content: "\e96d";
}

.hm-download:before {
    content: "\e96e";
}

.hm-drag-inside:before {
    content: "\e96f";
}

.hm-drag-outside:before {
    content: "\e970";
}

.hm-drag:before {
    content: "\e971";
}

.hm-drawer:before {
    content: "\e972";
}

.hm-dribbble:before {
    content: "\e973";
}

.hm-dropper:before {
    content: "\e974";
}

.hm-egg-fry:before {
    content: "\e975";
}

.hm-ellipsis-fill-h:before {
    content: "\e976";
}

.hm-ellipsis-fill-v:before {
    content: "\e977";
}

.hm-ellipsis-horizontal:before {
    content: "\e978";
}

.hm-ellipsis-vertical:before {
    content: "\e979";
}

.hm-emo-normal:before {
    content: "\e97a";
}

.hm-emo-sad:before {
    content: "\e97b";
}

.hm-emo-smile:before {
    content: "\e97c";
}

.hm-envelop:before {
    content: "\e97d";
}

.hm-facebook:before {
    content: "\e97e";
}

.hm-fancy-futton:before {
    content: "\e97f";
}

.hm-feeder:before {
    content: "\e980";
}

.hm-file-cabinet:before {
    content: "\e981";
}

.hm-file-rotate:before {
    content: "\e982";
}

.hm-file:before {
    content: "\e983";
}

.hm-files:before {
    content: "\e984";
}

.hm-film-roll:before {
    content: "\e985";
}

.hm-film:before {
    content: "\e986";
}

.hm-finger-index:before {
    content: "\e987";
}

.hm-finger-print:before {
    content: "\e988";
}

.hm-fire-flame:before {
    content: "\e989";
}

.hm-flag:before {
    content: "\e98a";
}

.hm-flip-card1:before {
    content: "\e98b";
}

.hm-flip-card2:before {
    content: "\e98c";
}

.hm-folder-network:before {
    content: "\e98d";
}

.hm-folder:before {
    content: "\e98e";
}

.hm-football:before {
    content: "\e98f";
}

.hm-footer:before {
    content: "\e990";
}

.hm-form:before {
    content: "\e991";
}

.hm-forward:before {
    content: "\e992";
}

.hm-fountain-pen:before {
    content: "\e993";
}

.hm-gender-female:before {
    content: "\e994";
}

.hm-gender-male:before {
    content: "\e995";
}

.hm-gender-sign:before {
    content: "\e996";
}

.hm-gender:before {
    content: "\e997";
}

.hm-ghost:before {
    content: "\e998";
}

.hm-gift-box:before {
    content: "\e999";
}

.hm-globe1:before {
    content: "\e99a";
}

.hm-globe2:before {
    content: "\e99b";
}

.hm-globe3:before {
    content: "\e99c";
}

.hm-globe4:before {
    content: "\e99d";
}

.hm-google:before {
    content: "\e99e";
}

.hm-graduate-cap:before {
    content: "\e99f";
}

.hm-graph-bar:before {
    content: "\e9a0";
}

.hm-graph-pie:before {
    content: "\e9a1";
}

.hm-graph:before {
    content: "\e9a2";
}

.hm-grid-even:before {
    content: "\e9a3";
}

.hm-grid-masonry:before {
    content: "\e9a4";
}

.hm-grid-twist:before {
    content: "\e9a5";
}

.hm-grid:before {
    content: "\e9a6";
}

.hm-group:before {
    content: "\e9a7";
}

.hm-hand-mike:before {
    content: "\e9a8";
}

.hm-hand-watch:before {
    content: "\e9a9";
}

.hm-hand:before {
    content: "\e9aa";
}

.hm-header:before {
    content: "\e9ab";
}

.hm-headphone:before {
    content: "\e9ac";
}

.hm-headset:before {
    content: "\e9ad";
}

.hm-heart-beat:before {
    content: "\e9ae";
}

.hm-hexa:before {
    content: "\e9af";
}

.hm-highlighter:before {
    content: "\e9b0";
}

.hm-home:before {
    content: "\e9b1";
}

.hm-hot-spot:before {
    content: "\e9b2";
}

.hm-hotdog:before {
    content: "\e9b3";
}

.hm-ice-cream:before {
    content: "\e9b4";
}

.hm-icon-box:before {
    content: "\e9b5";
}

.hm-imac:before {
    content: "\e9b6";
}

.hm-image-compare:before {
    content: "\e9b7";
}

.hm-image-slider:before {
    content: "\e9b8";
}

.hm-image:before {
    content: "\e9b9";
}

.hm-inbox:before {
    content: "\e9ba";
}

.hm-infinity:before {
    content: "\e9bb";
}

.hm-info:before {
    content: "\e9bc";
}

.hm-injection:before {
    content: "\e9bd";
}

.hm-instagram:before {
    content: "\e9be";
}

.hm-jar-chemical:before {
    content: "\e9bf";
}

.hm-key:before {
    content: "\e9c0";
}

.hm-language-change:before {
    content: "\e9c1";
}

.hm-laptop:before {
    content: "\e9c2";
}

.hm-layer:before {
    content: "\e9c3";
}

.hm-lens:before {
    content: "\e9c4";
}

.hm-like:before {
    content: "\e9c5";
}

.hm-line-graph-pointed:before {
    content: "\e9c6";
}

.hm-link:before {
    content: "\e9c7";
}

.hm-linkedin:before {
    content: "\e9c8";
}

.hm-linux:before {
    content: "\e9c9";
}

.hm-list-2:before {
    content: "\e9ca";
}

.hm-list-group:before {
    content: "\e9cb";
}

.hm-list:before {
    content: "\e9cc";
}

.hm-location-pointer:before {
    content: "\e9cd";
}

.hm-lock:before {
    content: "\e9ce";
}

.hm-logo-carousel:before {
    content: "\e9cf";
}

.hm-logo-grid:before {
    content: "\e9d0";
}

.hm-lotus:before {
    content: "\e9d1";
}

.hm-love:before {
    content: "\e9d2";
}

.hm-madel:before {
    content: "\e9d3";
}

.hm-magic-wand:before {
    content: "\e9d4";
}

.hm-magnet:before {
    content: "\e9d5";
}

.hm-mail-open:before {
    content: "\e9d6";
}

.hm-man-range:before {
    content: "\e9d7";
}

.hm-map-marker:before {
    content: "\e9d8";
}

.hm-map-pointer:before {
    content: "\e9d9";
}

.hm-measurement:before {
    content: "\e9da";
}

.hm-memory:before {
    content: "\e9db";
}

.hm-menu-price:before {
    content: "\e9dc";
}

.hm-micro-chip:before {
    content: "\e9dd";
}

.hm-microphone1:before {
    content: "\e9de";
}

.hm-microphone2:before {
    content: "\e9df";
}

.hm-mobile:before {
    content: "\e9e0";
}

.hm-money-bag:before {
    content: "\e9e1";
}

.hm-money:before {
    content: "\e9e2";
}

.hm-monitor:before {
    content: "\e9e3";
}

.hm-mouse:before {
    content: "\e9e4";
}

.hm-muscle:before {
    content: "\e9e5";
}

.hm-net:before {
    content: "\e9e6";
}

.hm-network1:before {
    content: "\e9e7";
}

.hm-network2:before {
    content: "\e9e8";
}

.hm-newspaper:before {
    content: "\e9e9";
}

.hm-nuclear-circle:before {
    content: "\e9ea";
}

.hm-office-file:before {
    content: "\e9eb";
}

.hm-pacman:before {
    content: "\e9ec";
}

.hm-paper-fold:before {
    content: "\e9ed";
}

.hm-paper-plane-alt:before {
    content: "\e9ee";
}

.hm-paper-plane:before {
    content: "\e9ef";
}

.hm-pause:before {
    content: "\e9f0";
}

.hm-pen-head:before {
    content: "\e9f1";
}

.hm-pen-pencil:before {
    content: "\e9f2";
}

.hm-pen-scale:before {
    content: "\e9f3";
}

.hm-pen-paper:before {
    content: "\e9f4";
}

.hm-pen:before {
    content: "\e9f5";
}

.hm-pencil:before {
    content: "\e9f6";
}

.hm-pendrive:before {
    content: "\e9f7";
}

.hm-phone:before {
    content: "\e9f8";
}

.hm-pillar:before {
    content: "\e9f9";
}

.hm-pin-man-range:before {
    content: "\e9fa";
}

.hm-pin-man:before {
    content: "\e9fb";
}

.hm-pin:before {
    content: "\e9fc";
}

.hm-plane:before {
    content: "\e9fd";
}

.hm-play-end:before {
    content: "\e9fe";
}

.hm-play-next:before {
    content: "\e9ff";
}

.hm-play-previous:before {
    content: "\ea00";
}

.hm-play-start:before {
    content: "\ea01";
}

.hm-play-button:before {
    content: "\ea02";
}

.hm-play-store:before {
    content: "\ea03";
}

.hm-play:before {
    content: "\ea04";
}

.hm-playing-card:before {
    content: "\ea05";
}

.hm-plus-box:before {
    content: "\ea06";
}

.hm-plus-circle:before {
    content: "\ea07";
}

.hm-plus-gap:before {
    content: "\ea08";
}

.hm-plus-open:before {
    content: "\ea09";
}

.hm-popup:before {
    content: "\ea0a";
}

.hm-power:before {
    content: "\ea0b";
}

.hm-printer:before {
    content: "\ea0c";
}

.hm-progress-bar:before {
    content: "\ea0d";
}

.hm-promo:before {
    content: "\ea0e";
}

.hm-pulse:before {
    content: "\ea0f";
}

.hm-puzzle:before {
    content: "\ea10";
}

.hm-question:before {
    content: "\ea11";
}

.hm-quote:before {
    content: "\ea12";
}

.hm-radar:before {
    content: "\ea13";
}

.hm-radiation:before {
    content: "\ea14";
}

.hm-reading-glass-alt:before {
    content: "\ea15";
}

.hm-reading-glass:before {
    content: "\ea16";
}

.hm-recycle-bin:before {
    content: "\ea17";
}

.hm-recycle:before {
    content: "\ea18";
}

.hm-refresh-time:before {
    content: "\ea19";
}

.hm-reply:before {
    content: "\ea1a";
}

.hm-responsive-device:before {
    content: "\ea1b";
}

.hm-review:before {
    content: "\ea1c";
}

.hm-rocket1:before {
    content: "\ea1d";
}

.hm-rocket2:before {
    content: "\ea1e";
}

.hm-rss:before {
    content: "\ea1f";
}

.hm-safety-cap:before {
    content: "\ea20";
}

.hm-safety-kit:before {
    content: "\ea21";
}

.hm-sand-watch:before {
    content: "\ea22";
}

.hm-scale:before {
    content: "\ea23";
}

.hm-scanner:before {
    content: "\ea24";
}

.hm-scissor:before {
    content: "\ea25";
}

.hm-screen:before {
    content: "\ea26";
}

.hm-search:before {
    content: "\ea27";
}

.hm-seo:before {
    content: "\ea28";
}

.hm-server-network:before {
    content: "\ea29";
}

.hm-server:before {
    content: "\ea2a";
}

.hm-share:before {
    content: "\ea2b";
}

.hm-shield:before {
    content: "\ea2c";
}

.hm-ship:before {
    content: "\ea2d";
}

.hm-shirt:before {
    content: "\ea2e";
}

.hm-shopping-bag1:before {
    content: "\ea2f";
}

.hm-shopping-bag2:before {
    content: "\ea30";
}

.hm-shopping-bag3:before {
    content: "\ea31";
}

.hm-shopping-bag4:before {
    content: "\ea32";
}

.hm-shuffle:before {
    content: "\ea33";
}

.hm-shutter:before {
    content: "\ea34";
}

.hm-sign-in:before {
    content: "\ea35";
}

.hm-sign-out:before {
    content: "\ea36";
}

.hm-sitemap1:before {
    content: "\ea37";
}

.hm-sitemap2:before {
    content: "\ea38";
}

.hm-skart:before {
    content: "\ea39";
}

.hm-skull:before {
    content: "\ea3a";
}

.hm-skyscraper:before {
    content: "\ea3b";
}

.hm-slider-doc:before {
    content: "\ea3c";
}

.hm-slider-h-range:before {
    content: "\ea3d";
}

.hm-slider-image:before {
    content: "\ea3e";
}

.hm-slider-range-h:before {
    content: "\ea3f";
}

.hm-slider-v-open:before {
    content: "\ea40";
}

.hm-slider-video:before {
    content: "\ea41";
}

.hm-slider:before {
    content: "\ea42";
}

.hm-smart-watch:before {
    content: "\ea43";
}

.hm-snow:before {
    content: "\ea44";
}

.hm-spa-face:before {
    content: "\ea45";
}

.hm-spa-stone-flower:before {
    content: "\ea46";
}

.hm-spa-stone:before {
    content: "\ea47";
}

.hm-spark:before {
    content: "\ea48";
}

.hm-speaker-off:before {
    content: "\ea49";
}

.hm-speaker-on:before {
    content: "\ea4a";
}

.hm-spoon-fork:before {
    content: "\ea4b";
}

.hm-spoon:before {
    content: "\ea4c";
}

.hm-star:before {
    content: "\ea4d";
}

.hm-step-flow:before {
    content: "\ea4e";
}

.hm-steps:before {
    content: "\ea4f";
}

.hm-stop-watch:before {
    content: "\ea50";
}

.hm-stop:before {
    content: "\ea51";
}

.hm-support-call:before {
    content: "\ea52";
}

.hm-tab:before {
    content: "\ea53";
}

.hm-table-lamp:before {
    content: "\ea54";
}

.hm-tablet:before {
    content: "\ea55";
}

.hm-tag:before {
    content: "\ea56";
}

.hm-target-arrow:before {
    content: "\ea57";
}

.hm-target:before {
    content: "\ea58";
}

.hm-target1:before {
    content: "\ea59";
}

.hm-team-carousel:before {
    content: "\ea5a";
}

.hm-team-member:before {
    content: "\ea5b";
}

.hm-tennis-ball:before {
    content: "\ea5c";
}

.hm-terminal:before {
    content: "\ea5d";
}

.hm-testimonial-carousel:before {
    content: "\ea5e";
}

.hm-testimonial:before {
    content: "\ea5f";
}

.hm-text-animation:before {
    content: "\ea60";
}

.hm-theatre:before {
    content: "\ea61";
}

.hm-tick-circle:before {
    content: "\ea62";
}

.hm-tick:before {
    content: "\ea63";
}

.hm-tickets:before {
    content: "\ea64";
}

.hm-tie-knot:before {
    content: "\ea65";
}

.hm-tie:before {
    content: "\ea66";
}

.hm-timeline:before {
    content: "\ea67";
}

.hm-toggle:before {
    content: "\ea68";
}

.hm-tools:before {
    content: "\ea69";
}

.hm-tree-square:before {
    content: "\ea6a";
}

.hm-twitter-bird:before {
    content: "\ea6b";
}

.hm-twitter:before {
    content: "\ea6c";
}

.hm-ufo:before {
    content: "\ea6d";
}

.hm-umbralla:before {
    content: "\ea6e";
}

.hm-unlock:before {
    content: "\ea6f";
}

.hm-up-down:before {
    content: "\ea70";
}

.hm-upload:before {
    content: "\ea71";
}

.hm-upward-top-right:before {
    content: "\ea72";
}

.hm-user-female:before {
    content: "\ea73";
}

.hm-user-id:before {
    content: "\ea74";
}

.hm-user-male:before {
    content: "\ea75";
}

.hm-video-camera:before {
    content: "\ea76";
}

.hm-water-drop:before {
    content: "\ea77";
}

.hm-weather-cloud-day:before {
    content: "\ea78";
}

.hm-weather-cloud:before {
    content: "\ea79";
}

.hm-weather-day-rain:before {
    content: "\ea7a";
}

.hm-weather-day-snow:before {
    content: "\ea7b";
}

.hm-weather-day-windy-rain:before {
    content: "\ea7c";
}

.hm-weather-flood:before {
    content: "\ea7d";
}

.hm-weather-night-cloud:before {
    content: "\ea7e";
}

.hm-weather-rain-alt:before {
    content: "\ea7f";
}

.hm-weather-rain:before {
    content: "\ea80";
}

.hm-weather-snow:before {
    content: "\ea81";
}

.hm-weather-sun-rain:before {
    content: "\ea82";
}

.hm-weather-sun:before {
    content: "\ea83";
}

.hm-weather-sunny-day:before {
    content: "\ea84";
}

.hm-weather-thunder:before {
    content: "\ea85";
}

.hm-weather-windy-rain:before {
    content: "\ea86";
}

.hm-webcam1:before {
    content: "\ea87";
}

.hm-webcam2:before {
    content: "\ea88";
}

.hm-weight-scale:before {
    content: "\ea89";
}

.hm-windows:before {
    content: "\ea8a";
}

.hm-wine-glass2:before {
    content: "\ea8b";
}

.hm-wine-glass:before {
    content: "\ea8c";
}

.hm-worker-cap:before {
    content: "\ea8d";
}

.hm-youtube:before {
    content: "\ea8e";
}

.hm-centralize:before {
    content: "\ea8f";
}

.hm-add-section:before {
    content: "\ea90";
}

.hm-advanced-heading:before {
    content: "\ea91";
}

.hm-air-baloon:before {
    content: "\ea92";
}

.hm-arrow2:before {
    content: "\ea93";
}

.hm-bicycle2:before {
    content: "\ea94";
}

.hm-bond2:before {
    content: "\ea95";
}

.hm-bond3:before {
    content: "\ea96";
}

.hm-bond4:before {
    content: "\ea97";
}

.hm-calendar2:before {
    content: "\ea98";
}

.hm-carousel:before {
    content: "\ea99";
}

.hm-code-page:before {
    content: "\ea9a";
}

.hm-comment-circle:before {
    content: "\ea9b";
}

.hm-comment-square:before {
    content: "\ea9c";
}

.hm-copy:before {
    content: "\ea9d";
}

.hm-cursor:before {
    content: "\ea9e";
}

.hm-envelop2:before {
    content: "\ea9f";
}

.hm-factory:before {
    content: "\eaa0";
}

.hm-finger-point:before {
    content: "\eaa1";
}

.hm-finger-swipe-both:before {
    content: "\eaa2";
}

.hm-finger-swipe-corner:before {
    content: "\eaa3";
}

.hm-finger-swipe-left:before {
    content: "\eaa4";
}

.hm-finger-swipe-up:before {
    content: "\eaa5";
}

.hm-finger-swipe:before {
    content: "\eaa6";
}

.hm-finger-touch:before {
    content: "\eaa7";
}

.hm-folder-network:before {
    content: "\eaa8";
}

.hm-folder-sync:before {
    content: "\eaa9";
}

.hm-graph-bar2:before {
    content: "\eaaa";
}

.hm-graph-pie2:before {
    content: "\eaab";
}

.hm-heading-h:before {
    content: "\eaac";
}

.hm-heading-html:before {
    content: "\eaad";
}

.hm-heart:before {
    content: "\eaae";
}

.hm-home2:before {
    content: "\eaaf";
}

.hm-indent-left:before {
    content: "\eab0";
}

.hm-indent-right:before {
    content: "\eab1";
}

.hm-lock-close:before {
    content: "\eab2";
}

.hm-lock-open:before {
    content: "\eab3";
}

.hm-map-pointer-add:before {
    content: "\eab4";
}

.hm-map-pointer-check:before {
    content: "\eab5";
}

.hm-map-pointer-delete:before {
    content: "\eab6";
}

.hm-map-pointer2:before {
    content: "\eab7";
}

.hm-map:before {
    content: "\eab8";
}

.hm-navigation1:before {
    content: "\eab9";
}

.hm-navigation2:before {
    content: "\eaba";
}

.hm-page-export:before {
    content: "\eabb";
}

.hm-page-sync:before {
    content: "\eabc";
}

.hm-piramid:before {
    content: "\eabd";
}

.hm-plug:before {
    content: "\eabe";
}

.hm-point-marker:before {
    content: "\eabf";
}

.hm-quote2:before {
    content: "\eac0";
}

.hm-refresh-check:before {
    content: "\eac1";
}

.hm-refresh:before {
    content: "\eac2";
}

.hm-refresh2:before {
    content: "\eac3";
}

.hm-scrolling-image:before {
    content: "\eac4";
}

.hm-sign-turn-right:before {
    content: "\eac5";
}

.hm-speedometer:before {
    content: "\eac6";
}

.hm-sticky:before {
    content: "\eac7";
}

.hm-sync-cloud:before {
    content: "\eac8";
}

.hm-sync:before {
    content: "\eac9";
}

.hm-sync2:before {
    content: "\eaca";
}

.hm-table-lamp2:before {
    content: "\eacb";
}

.hm-target2:before {
    content: "\eacc";
}

.hm-timeline-spiral:before {
    content: "\eacd";
}

.hm-tv:before {
    content: "\eace";
}

.hm-vespa:before {
    content: "\eacf";
}

.hm-happyaddons:before {
    content: "\ead0";
}

.hm-brain:before {
    content: "\ead1";
}

.hm-breadcrumbs:before {
    content: "\ead2";
}

.hm-circular-chat:before {
    content: "\ead3";
}

.hm-currency-exchange:before {
    content: "\ead4";
}

.hm-cta:before {
    content: "\ead5";
}

.hm-data-table:before {
    content: "\ead6";
}

.hm-display-condition:before {
    content: "\ead7";
}

.hm-digital-memory:before {
    content: "\ead8";
}

.hm-dollar-box:before {
    content: "\ead9";
}

.hm-faq:before {
    content: "\eada";
}

.hm-facebook-feed:before {
    content: "\eadb";
}

.hm-header-footer:before {
    content: "\eadc";
}

.hm-heart:before {
    content: "\eadd";
}

.hm-image-accordion:before {
    content: "\eade";
}

.hm-image-masking:before {
    content: "\eadf";
}

.hm-instagram:before {
    content: "\eae0";
}

.hm-mail-chimp:before {
    content: "\eae1";
}

.hm-minus-large:before {
    content: "\eae2";
}

.hm-minus-small:before {
    content: "\eae3";
}

.hm-mobile-chat:before {
    content: "\eae4";
}

.hm-motion-button:before {
    content: "\eae5";
}

.hm-news-ticker:before {
    content: "\eae6";
}

.hm-offcanvas-menu:before {
    content: "\eae7";
}

.hm-post-grid:before {
    content: "\eae8";
}

.hm-post-list:before {
    content: "\eae9";
}

.hm-post-tab:before {
    content: "\eaea";
}

.hm-pricing-menu:before {
    content: "\eaeb";
}

.hm-scheduled-section:before {
    content: "\eaec";
}

.hm-section-link:before {
    content: "\eaed";
}

.hm-sticky-video:before {
    content: "\eaee";
}

.hm-section-nesting:before {
    content: "\eaef";
}

.hm-traffic-signal:before {
    content: "\eaf0";
}

.hm-tshirt:before {
    content: "\eaf1";
}

.hm-twitter-feed:before {
    content: "\eaf2";
}

.hm-grid-layout:before {
    content: "\eaf3";
}

.hm-add-to-cart-button:before {
    content: "\eaf4";

}

.hm-billing-address:before {
    content: "\eaf5";

}

.hm-cart:before {
    content: "\eaf6";

}

.hm-Category-Carousel:before {
    content: "\eaf7";

}

.hm-Category-Grid:before {
    content: "\eaf8";

}

.hm-Category-List:before {
    content: "\eaf9";

}

.hm-checkout-1:before {
    content: "\eafa";

}

.hm-checkout-2:before {
    content: "\eafb";

}

.hm-compare:before {
    content: "\eafc";

}

.hm-edit-menu:before {
    content: "\eafd";

}

.hm-facebook-review:before {
    content: "\eafe";

}

.hm-fb-messanger:before {
    content: "\eaff";

}

.hm-filter:before {
    content: "\eb00";

}

.hm-google-review:before {
    content: "\eb01";

}

.hm-grid-filter:before {
    content: "\eb02";

}

.hm-home3:before {
    content: "\eb03";

}

.hm-horizontal-timeline:before {
    content: "\eb04";

}

.hm-image-scroll:before {
    content: "\eb05";

}

.hm-mini-cart:before {
    content: "\eb06";

}

.hm-off-canvas-cart:before {
    content: "\eb07";

}

.hm-popup1:before {
    content: "\eb08";

}

.hm-post-list:before {
    content: "\eb09";

}

.hm-Product-Carousel:before {
    content: "\eb0a";

}

.hm-product-filter:before {
    content: "\eb0b";

}

.hm-product-gallery:before {
    content: "\eb0c";

}

.hm-Product-Grid:before {
    content: "\eb0d";

}

.hm-Product-List-double:before {
    content: "\eb0e";

}

.hm-product-list-single:before {
    content: "\eb0f";

}

.hm-product-rating:before {
    content: "\eb10";

}

.hm-product-table:before {
    content: "\eb11";

}

.hm-product-variation:before {
    content: "\eb12";

}

.hm-retina-image:before {
    content: "\eb13";

}

.hm-shipping-address:before {
    content: "\eb14";

}

.hm-shop:before {
    content: "\eb15";

}

.hm-shopping-details:before {
    content: "\eb16";

}

.hm-sticky-video-2:before {
    content: "\eb17";

}

.hm-Template-Import:before {
    content: "\eb18";

}

.hm-trendy-product:before {
    content: "\eb19";

}

.hm-user-check:before {
    content: "\eb1a";

}

.hm-User-Circle:before {
    content: "\eb1b";

}

.hm-user-plus:before {
    content: "\eb1c";

}

.hm-user:before {
    content: "\eb1d";

}

.hm-video-gallery:before {
    content: "\eb1e";

}

.hm-wishlist:before {
    content: "\eb1f";

}
