{% extends "djangocms_frontend.html" %}{% load cms_tags menu_tags %}
{% block base_css %}
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.1/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-iYQeCzEYFbKjA/T2uDLTpkwGzCiq6soy8tYaI1GyVh/UjpbCx/TYkiZhlZB6+fzT" crossorigin="anonymous"/>
{% endblock %}
{% block base_js %}
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.1/dist/js/bootstrap.bundle.min.js" integrity="sha384-u1OknCvxWvY5kfmNBILK2hRnQC3Pr17a+RTT6rIHI7NnikvbZlHgTPOOmMi466C8" crossorigin="anonymous"></script>
{% endblock %}
{% block navbar %}
    <nav class="navbar {% block navbar_options %}navbar-expand-lg navbar-dark bg-dark{% endblock %}">
        <div class="container">
            <a class="navbar-brand" href="/">{% block brand %}{% endblock %}</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarSupportedContent">
                <ul class="navbar-nav me-auto mb-2 mb-lg-0">{% block menubar %}{% show_menu 0 100 0 100 'bootstrap5/menu.html' %}{% endblock %}</ul>
                {% block searchbar %}{% endblock %}
            </div>
        </div>
    </nav>
{% endblock %}
{% block bottom_css %} {# Quick check for dark mode #}
    <style>
        @media (prefers-color-scheme: dark) {
            :root {
                --bs-body-bg: #1e1e1e;
                --bs-body-bg-rgb: 30, 30, 30;
                --bs-body-color: #FFF;
                --bs-body-color-rgb: 255, 255, 255;
                --bs-dark: #3D3D3D;
                --bs-dark-rgb: 61, 61, 61;
                --bs-light: #c4c4c4;
                --bs-light-rgb: 196, 196, 196;
            }
        }
        :root[data-color-scheme="dark"] {
                --bs-body-bg: #1e1e1e;
                --bs-body-bg-rgb: 30, 30, 30;
                --bs-body-color: #FFF;
                --bs-body-color-rgb: 255, 255, 255;
                --bs-dark: #3D3D3D;
                --bs-dark-rgb: 61, 61, 61;
                --bs-light: #c4c4c4;
                --bs-light-rgb: 196, 196, 196;
            }
        }

    </style>
    {{ block.super }}
{% endblock %}
