{% extends "djangocms_frontend/admin/base.html" %}
{% load static i18n frontend %}

{% block extrahead %}
    {{ block.super }}
    <script src="{% static 'djangocms_frontend/js/bundle.grid.js' %}"></script>
{% endblock %}

{% block field_sets %}{% spaceless %}
    <div class="djangocms-frontend djangocms-frontend-row" data-static="{% get_static_prefix %}"
         data-sizes='{% framework_info "grid_sizes" %}'
         data-icons='{% framework_info "grid_icons" %}'
         data-rows='["{% trans "Colums per row" %}"]'
         data-links='{% framework_info "row_links" %}'
    >
        {{ block.super }}
    </div>{% endspaceless %}
{% endblock %}
{% block custom_class %}frontend-grid-icons {{ block.super }}{% endblock %}
