{% load cms_tags frontend %}
{% spaceless %}
    <{{ instance.tag_type }}{{ instance.get_attributes }}
    id="parent-{{ instance.pk|safe }}"
    data-bs-children="{{ instance.collapse_siblings }}"
    role="tablist"
    >
    {% with parent=instance %}
        {% for plugin in instance.child_plugin_instances %}
            {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
        {% endfor %}
    {% endwith %}
    </{{ instance.tag_type }}>
{% endspaceless %}
