{% load cms_tags frontend %}
{% spaceless %}
    <{{ instance.tag_type }}{{ instance.get_attributes }}
    id="{{ instance.container_identifier }}"
    role="tabpanel"
    data-bs-parent="#parent-{{ parent.pk|safe }}"
    aria-labelledby="trigger-{{ instance.container_identifier }}"
    >
    {% for plugin in instance.child_plugin_instances %}
        {% with forloop as parentloop %}{% render_plugin plugin %}{% endwith %}
    {% endfor %}
    </{{ instance.tag_type }}>
{% endspaceless %}
