{% load cms_tags frontend %}
{% spaceless %}
    <{{ instance.tag_type }} {{ instance.get_attributes }}>
        <div class="flex-shrink-0">
            {% for plugin in instance.child_plugin_instances %}
                {% if plugin.plugin_type == "MediaBodyPlugin" %}
                    </div>
                {% endif %}
                {% with forloop=parentloop %}{% render_plugin plugin %}{% endwith %}
            {% endfor %}
    </{{ instance.tag_type }}>
{% endspaceless %}
