{% load i18n cms_tags %}<{{ instance.code_type }}{{ instance.get_attributes }}>{% if instance.tag_type == 'pre' %}<code>{% endif %}{{ instance.code_content }}{% if instance.tag_type == 'pre' %}</code>{% endif %}</{{ instance.code_type }}>
