{% extends "djangocms_frontend/admin/base.html" %}
{% load static %}

{% block field_sets %}
    <div class="djangocms-frontend djangocms-frontend-container" data-static="{% get_static_prefix %}">
        {{ block.super }}
    </div>
{% endblock %}
