{% load cms_tags %}
{% spaceless %}
    <{{ instance.tag_type }}{{ instance.get_attributes }} id="parent-{{ instance.pk|safe }}">
        {% for plugin in instance.child_plugin_instances %}
            {% with parentloop=forloop parent=instance %}{% render_plugin plugin %}{% endwith %}
        {% endfor %}
    </{{ instance.tag_type }}>
{% endspaceless %}
