{% load cms_tags sekizai_tags icon_tags %}{% add_css_for_icon instance.icon %}{% spaceless %}
    <{{ instance.tag_type }}{{ instance.get_attributes }}>
    {% for plugin in instance.child_plugin_instances %}
        {% with parentloop=forloop parent=instance %}{% render_plugin plugin %}{% endwith %}
    {% empty %}{{ instance.simple_content }}{% endfor %}{{ icon_text }}
    </{{ instance.tag_type }}>{% endspaceless %}
