{% load cms_tags i18n %}{% spaceless %}
    <{{ instance.tag_type }}{{ instance.get_attributes }} role="alert">
    {% if instance.alert_dismissible %}
        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="{% trans "Close" %}"></button>
    {% endif %}
    <div>
        {% for plugin in instance.child_plugin_instances %}
            {% with parent=instance %}{% render_plugin plugin %}{% endwith %}
        {% endfor %}
    </div>
    </{{ instance.tag_type }}>
{% endspaceless %}
