# Generated by Django 3.1.8 on 2022-01-23 21:37

from django.db import migrations

import djangocms_frontend.contrib.image.models
import djangocms_frontend.contrib.link.models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("djangocms_frontend", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Image",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
                "verbose_name": "Image",
            },
            bases=(
                djangocms_frontend.contrib.link.models.GetLinkMixin,
                djangocms_frontend.contrib.image.models.ImageMixin,
                "djangocms_frontend.frontenduiitem",
            ),
        ),
    ]
