/*
    This file is generated.
    Do not edit directly.
    Edit original files in
    /private/sass instead
 */ 

@media screen{.change-form .select2-container--default .select2-selection--single,.change-form .select2-dropdown{background:var(--dca-white,var(--body-bg,#fff))}.change-form .select2-container--default .select2-results__option[aria-selected=true]{background:var(--dca-gray,var(--body-quiet-color,#666))}.change-form .select2-container--default .select2-selection--single .select2-selection__rendered{color:var(--dca-black,var(--body-fg,#000))}.change-form .popover{background:var(--dca-white,var(--body-bg,#fff))}}